--drop database colabcms;
create database colabcms;
use colabcms;

create table event
-- event is both a calender(booked event) or a new item. this makes the comment system universal.
(
	eventID int(11) NOT NULL PRIMARY KEY AUTO_INCREMENT,
	date datetime,
	end datetime,
	submitted datetime,
	userID int(11),
	genreID int(11),
	title char(255),
	description char(255),
	content text,
	location char(255),
	approved enum('Y','N')
);

create table user
-- user is also artist as listed under event/news submission or booking.
-- this keeps the bio information
-- user infromation easy to deal with.
(
	userID int(11) NOT NULL PRIMARY KEY AUTO_INCREMENT,
	username char(24),
	password char(45),
	email char(32),
	url	char(255),
	instantmessageID int(11),
	instantmessage char(128),
	profile char(255),
	countryID int(11),
	city char(255),
	groupID int(11)
);

create table groups
(
	groupID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	groupDesc char(16)
);

create table genre
-- this is the event/news genre. we will populate this with data such as
-- audio, video,  (for event type) digital art news, announcements, share announcements, 
-- performances (for news type)
(	
	genreID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	genretype char(64)
);

create table comment
-- the comment table is for event/news. we track the user who posted, what event its for, date, and the comment.
(
	commentID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	eventID int(11),
	userID int(11),
	date datetime,
	comment text
);

create table multimedia
-- multimedia is associated with event/news, and can show up in the detailed view of an event/news thread.
-- we track what event its for, where it is located (url), description, who posted it, and the time it was posted
(
	multimediaID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	multimediatypeID int(11),
	url char(255),
	title char(32),
	description char(255),
	eventID int(11),
	userID int(11),
	date datetime,
	approved enum('Y','N'),
	licenseID int(11)  
);

create table multimediacomment
(
	multimediacommentID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	multimediaID int(11),
	userID int(11),
	date datetime,
	comment text
);

create table metadata
-- meatadata in the DB not on disk, fool...
(
	metadataID int(11) NOT NULL PRIMARY KEY AUTO_INCREMENT,
	multimediaID int(11),
	metadataKeyName char(32),
	metadataKeyValue text
)

create table multimediatype
-- what kind of multimedia ? text, audio, video, flash, ? this is mainly used for formatting dislplay output on the page
(
	mutlimediatypeID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	multimediatype char(64)
);

create table country
-- for use in user table
(
	countryID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	countryname char(255)
);

create table instantmessage
(
	instantmessageID int(11)   NOT NULL PRIMARY KEY AUTO_INCREMENT,
	instantmessagetype char(16)
);

create table keyword
(
	keywordID int(11)   not null primary key auto_increment,
	keyword char(32) not null,
	link char(32) not null
);

create table links
(
	linkID int(11) not null primary key auto_increment,
	parentID int(11),
	title varchar(255),
	folder enum('Y', 'N'),
	approved enum('Y', 'N'),
	url text,
	description text,
	userID int(11)	
);

-- insert basic data

insert into groups values('null', 'basic');
insert into groups values('null', 'moderator');
insert into groups values('null', 'admin');


insert into instantmessage values('null', 'AIM');
insert into instantmessage values('null', 'MSN');
insert into instantmessage values('null', 'ICQ');
insert into instantmessage values('null', 'IRC');


insert into genre values('null', 'SITENAME');
insert into genre values('null', 'non-SITENAME');
insert into genre values('null', 'announcement');
insert into genre values('null', 'interview');
insert into genre values('null', 'review');
insert into genre values('null', 'article');
insert into genre values('null', 'concert');
insert into genre values('null', 'performance');


insert into multimediatype values('null', 'Picture');
insert into multimediatype values('null', 'Audio');
insert into multimediatype values('null', 'Video');
insert into multimediatype values('null', 'Flash');
insert into multimediatype values('null', 'Text/PDF');

insert into country values(null, 'Albania ');
insert into country values(null, 'Algeria');
insert into country values(null, 'Andorra ');
insert into country values(null, 'Angola');
insert into country values(null, 'Antigua and Barbuda ');
insert into country values(null, 'Argentina');
insert into country values(null, 'Armenia');
insert into country values(null, 'Australia ');
insert into country values(null, 'Austria');
insert into country values(null, 'Azerbaijan ');
insert into country values(null, 'Bahamas');
insert into country values(null, 'Bahrain ');
insert into country values(null, 'Bangladesh ');
insert into country values(null, 'Barbados ');
insert into country values(null, 'Belarus ');
insert into country values(null, 'Belgium');
insert into country values(null, 'Belize ');
insert into country values(null, 'Benin');
insert into country values(null, 'Bhutan');
insert into country values(null, 'Bolivia ');
insert into country values(null, 'Bosnia and Herzegovina ');
insert into country values(null, 'Botswana ');
insert into country values(null, 'Brazil');
insert into country values(null, 'Brunei ');
insert into country values(null, 'Bulgaria ');
insert into country values(null, 'Burkina Faso');
insert into country values(null, 'Burundi');
insert into country values(null, 'Cambodia ');
insert into country values(null, 'Cameroon');
insert into country values(null, 'Canada');
insert into country values(null, 'Cape Verde');
insert into country values(null, 'Central African Republic');
insert into country values(null, 'Chad');
insert into country values(null, 'Chile');
insert into country values(null, 'China ');
insert into country values(null, 'Colombia ');
insert into country values(null, 'Comoros');
insert into country values(null, 'CongoBrazzaville ');
insert into country values(null, 'Congo, Democratic Republic of the');
insert into country values(null, 'Costa Rica');
insert into country values(null, 'Croatia ');
insert into country values(null, 'Cuba');
insert into country values(null, 'Cyprus');
insert into country values(null, 'Czech Republic');
insert into country values(null, 'Cote d\'Ivoire');
insert into country values(null, 'Denmark');
insert into country values(null, 'Djibouti');
insert into country values(null, 'Dominica ');
insert into country values(null, 'Dominican Republic');
insert into country values(null, 'East TimorTimor Timur ');
insert into country values(null, 'Ecuador ');
insert into country values(null, 'Egypt');
insert into country values(null, 'El Salvador ');
insert into country values(null, 'Equatorial Guinea');
insert into country values(null, 'Eritrea');
insert into country values(null, 'Estonia ');
insert into country values(null, 'Ethiopia ');
insert into country values(null, 'Fiji ');
insert into country values(null, 'Finland');
insert into country values(null, 'France ');
insert into country values(null, 'Gabon');
insert into country values(null, 'Gambia, The');
insert into country values(null, 'Georgia ');
insert into country values(null, 'Germany ');
insert into country values(null, 'Ghana ');
insert into country values(null, 'Greece');
insert into country values(null, 'Grenada ');
insert into country values(null, 'Guatemala ');
insert into country values(null, 'Guinea');
insert into country values(null, 'Guinea-Bissau');
insert into country values(null, 'Guyana');
insert into country values(null, 'Haiti ');
insert into country values(null, 'Honduras ');
insert into country values(null, 'Hungary');
insert into country values(null, 'Iceland');
insert into country values(null, 'India ');
insert into country values(null, 'Indonesia');
insert into country values(null, 'Iran');
insert into country values(null, 'Iraq');
insert into country values(null, 'Ireland ');
insert into country values(null, 'Israel');
insert into country values(null, 'Italy ');
insert into country values(null, 'Jamaica ');
insert into country values(null, 'Japan');
insert into country values(null, 'Jordan ');
insert into country values(null, 'Kazakhstan ');
insert into country values(null, 'Kenya ');
insert into country values(null, 'Kiribati');
insert into country values(null, 'Korea, North ');
insert into country values(null, 'Korea, South');
insert into country values(null, 'Kuwait ');
insert into country values(null, 'Kyrgyzstan');
insert into country values(null, 'Laos ');
insert into country values(null, 'Latvia ');
insert into country values(null, 'Lebanon ');
insert into country values(null, 'Lesotho');
insert into country values(null, 'Liberia');
insert into country values(null, 'Libya');
insert into country values(null, 'Liechtenstein');
insert into country values(null, 'Lithuania ');
insert into country values(null, 'Luxembourg ');
insert into country values(null, 'Macedonia, Former Yugoslav Republic of ');
insert into country values(null, 'Madagascar');
insert into country values(null, 'Malawi ');
insert into country values(null, 'Malaysia');
insert into country values(null, 'Maldives ');
insert into country values(null, 'Mali');
insert into country values(null, 'Malta ');
insert into country values(null, 'Marshall Islands');
insert into country values(null, 'Mauritania');
insert into country values(null, 'Mauritius ');
insert into country values(null, 'Mexico');
insert into country values(null, 'Micronesia, Federated States of ');
insert into country values(null, 'Moldova');
insert into country values(null, 'Monaco ');
insert into country values(null, 'Mongolia ');
insert into country values(null, 'Morocco');
insert into country values(null, 'Mozambique');
insert into country values(null, 'Myanmar ');
insert into country values(null, 'Namibia ');
insert into country values(null, 'Nauru');
insert into country values(null, 'Nepal ');
insert into country values(null, 'Netherlands ');
insert into country values(null, 'New Zealand ');
insert into country values(null, 'Nicaragua ');
insert into country values(null, 'Niger');
insert into country values(null, 'Nigeria ');
insert into country values(null, 'Norway');
insert into country values(null, 'Oman ');
insert into country values(null, 'Pakistan');
insert into country values(null, 'Palau');
insert into country values(null, 'Panama');
insert into country values(null, 'Papua New Guinea ');
insert into country values(null, 'Paraguay');
insert into country values(null, 'Peru ');
insert into country values(null, 'Philippines');
insert into country values(null, 'Poland');
insert into country values(null, 'Portugal');
insert into country values(null, 'Qatar ');
insert into country values(null, 'Romania');
insert into country values(null, 'Russia');
insert into country values(null, 'Rwanda');
insert into country values(null, 'Saint Kitts and Nevis');
insert into country values(null, 'Saint Lucia ');
insert into country values(null, 'Saint Vincent and The Grenadines');
insert into country values(null, 'Samoa');
insert into country values(null, 'San Marino');
insert into country values(null, 'Sao Tome and Principe');
insert into country values(null, 'Saudi Arabia ');
insert into country values(null, 'Senegal');
insert into country values(null, 'Serbia and Montenegro ');
insert into country values(null, 'Seychelles ');
insert into country values(null, 'Sierra Leone');
insert into country values(null, 'Singapore');
insert into country values(null, 'Slovakia ');
insert into country values(null, 'Slovenia ');
insert into country values(null, 'Solomon Islands');
insert into country values(null, 'Somalia');
insert into country values(null, 'South Africa');
insert into country values(null, 'Spain ');
insert into country values(null, 'Sri Lanka');
insert into country values(null, 'Sudan ');
insert into country values(null, 'Suriname');
insert into country values(null, 'Swaziland');
insert into country values(null, 'Sweden');
insert into country values(null, 'Switzerland');
insert into country values(null, 'Syria ');
insert into country values(null, 'Taiwan');
insert into country values(null, 'Tajikistan');
insert into country values(null, 'Tanzania ');
insert into country values(null, 'Thailand');
insert into country values(null, 'Togo');
insert into country values(null, 'Tonga ');
insert into country values(null, 'Trinidad and Tobago ');
insert into country values(null, 'Tunisia ');
insert into country values(null, 'Turkey');
insert into country values(null, 'Turkmenistan');
insert into country values(null, 'Tuvalu');
insert into country values(null, 'Uganda ');
insert into country values(null, 'Ukraine');
insert into country values(null, 'United Arab Emirates ');
insert into country values(null, 'United Kingdom');
insert into country values(null, 'United States');
insert into country values(null, 'Uruguay ');
insert into country values(null, 'Uzbekistan');
insert into country values(null, 'Vanuatu');
insert into country values(null, 'Vatican City');
insert into country values(null, 'Venezuela ');
insert into country values(null, 'Vietnam');
insert into country values(null, 'Western Sahara');
insert into country values(null, 'Yemen ');
insert into country values(null, 'Zambia');
insert into country values(null, 'Zimbabwe'); 

-- insert default admin user with admin privs.
insert into user values(null, 'admin', password('123456'), 'admin@domain.com', 'http://127.0.0.1', '1','admin', 'default profile', '1', 'City', '3');

-- add defaut mysql user
grant select, insert, update, delete
on sharecms.*
to sharecmsuser@localhost identified by 'sharecmspassword';

-- MAYE HAVE TO DO THIS FOR BACKWARDS COMPATIBILITY: SET PASSWORD FOR sharecmsuser@localhost = OLD_PASSWORD('sharecmspassword');